pub trait ToolCallLauncher<B>: Send {
// Required method
fn launch_stage<'a>(
&'a mut self,
text: String,
boxes: Vec<B>,
) -> Pin<Box<dyn Future<Output = Result<(), String>> + Send + 'a>>;
}Expand description
Accepts one assistant-text and tool-call wave for durable launch.
Required Methods
Sourcefn launch_stage<'a>(
&'a mut self,
text: String,
boxes: Vec<B>,
) -> Pin<Box<dyn Future<Output = Result<(), String>> + Send + 'a>>
fn launch_stage<'a>( &'a mut self, text: String, boxes: Vec<B>, ) -> Pin<Box<dyn Future<Output = Result<(), String>> + Send + 'a>>
Completes every consumer-required step before this wave may be acknowledged.
Success includes optional same-turn steering. Failure can follow durable acceptance or launch, does not certify replayability, and causes the shim to acknowledge none of the wave and remain unusable.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".